package de.nwsnet.homework.eurocalc;

/*
 * Copyright (c) 2002, 2003 Jochen Kupperschmidt <jochen@kupperschmidt.de>
 * Released under the terms of the GNU General Public License
 *    _                               _
 *   | |_ ___ _____ ___ _ _ _ ___ ___| |_
 *   |   | . |     | ._| | | | . |  _| . /
 *   |_|_|___|_|_|_|___|_____|___|_| |_|_\
 *     http://homework.nwsnet.de/
 */

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Enumeration;
import java.util.Iterator;
import java.util.Vector;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.ImageIcon;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;

/**
 * A currency representation holding name and value in euro.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 28-Mar-2003
 */
class CurrencyDialog extends JDialog implements ActionListener {

    public CurrencyDialog(JFrame owner, Currencies currencies) {
        super(owner, "Currencies", true);
        setResizable(false);
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);

		// column names
		Vector columnNames = new Vector();
		columnNames.addElement("Flag");
		columnNames.addElement("Long Name");
		columnNames.addElement("Short Name");
		columnNames.addElement("Euro Value");

		// cell data
		Currency c;
		Vector data = new Vector();
		Vector dataTmp;
		Iterator it = currencies.getCurrencies().iterator();
		while (it.hasNext()) {
			c = (Currency) it.next();
			dataTmp = new Vector();
			dataTmp.addElement(Resources.getIcon(c.getShortName() + "_ICON"));
			dataTmp.addElement(c.getLongName());
			dataTmp.addElement(c.getShortName());
			dataTmp.addElement(Double.toString(c.getEuroValue()));
			data.addElement(dataTmp);
        }

		// create table with own model
		DefaultTableModel tableModel = new DefaultTableModel() {
			public boolean isCellEditable(int row, int column) {
				return false;
			}
		};
		tableModel.setDataVector(data, columnNames);
        JTable table = new JTable(tableModel);
        table.setCellSelectionEnabled(false);
        table.setFocusable(false);

		// set cell renderers
        findTableColumn(table, 0).setCellRenderer(
            table.getDefaultRenderer(ImageIcon.class));

		// add table to scrollable pane with title
        JScrollPane tablePane = new JScrollPane(table);
        tablePane.setPreferredSize(new Dimension(400, 200));

		// create close button
        JButton closeButton = new JButton("OK");
        closeButton.setAlignmentX(CENTER_ALIGNMENT);
        closeButton.setFocusPainted(false);
        closeButton.addActionListener(this);

		// add components to content pane
        JPanel contentPane = new JPanel();
        contentPane.setBorder(BorderFactory.createEmptyBorder(4, 4, 4, 4));
        contentPane.setLayout(new BoxLayout(contentPane, BoxLayout.Y_AXIS));
        contentPane.add(tablePane);
        contentPane.add(Box.createVerticalStrut(4));
        contentPane.add(closeButton);
        getContentPane().add(contentPane);
        pack();
    }

    public TableColumn findTableColumn(JTable table, int columnModelIndex) {
        Enumeration enum = table.getColumnModel().getColumns();
        while (enum.hasMoreElements()) {
            TableColumn col = (TableColumn)enum.nextElement();
            if (col.getModelIndex() == columnModelIndex) {
                return col;
            }
        }
        return null;
    }

    public void actionPerformed(ActionEvent ae) {
        setVisible(false);
    }

	// overwrite to re-center dialog on parent frame
    public void setVisible(boolean visible) {
        setLocationRelativeTo(getOwner());
        super.setVisible(visible);
    }
}
