package de.nwsnet.homework.eurocalc;

/*
 * Copyright (c) 2002, 2003 Jochen Kupperschmidt <jochen@kupperschmidt.de>
 * Released under the terms of the GNU General Public License
 *    _                               _
 *   | |_ ___ _____ ___ _ _ _ ___ ___| |_
 *   |   | . |     | ._| | | | . |  _| . /
 *   |_|_|___|_|_|_|___|_____|___|_| |_|_\
 *     http://homework.nwsnet.de/
 */

import java.awt.BorderLayout;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.NumberFormat;
import java.text.ParseException;

import javax.swing.BorderFactory;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.text.JTextComponent;

/**
 * Converts from euro to a choosable currency and vice versa.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 28-Mar-2003
 */
public class EuroCalc extends JFrame implements ActionListener {

    private Currencies curr = new Currencies();
    private NumberFormat nf = NumberFormat.getInstance();
    private boolean locked = false;

    private JLabel euroLabel;
    private JLabel convLabel;
    private LimitedCharSetField euroField;
    private LimitedCharSetField convField;

    public EuroCalc() {
        // add currencies to convert to and from
		String[] shortNames = { "ATS", "BEF", "DEM", "ESP", "FIM", "FRF",
			                    "GRD", "IEP", "ITL", "LUF", "NLG", "PTE"};
		for (int i = 0; i < shortNames.length; i++) {
			curr.addCurrency(
					Resources.getString(shortNames[i] + "_NAME"),
					shortNames[i],
                    Double.parseDouble(
                        Resources.getString(shortNames[i] + "_EURO"))
			);
		}

		// set default currency
		curr.setCurrency("DEM");

		// set digits to show
        nf.setMinimumIntegerDigits(1);
        nf.setMinimumFractionDigits(2);
        nf.setMaximumFractionDigits(2);

		// add menu bar
        setJMenuBar(new MenuBar(this, curr));

        // create fields
        String validChars = "0123456789,.";
        euroField = new LimitedCharSetField(validChars, 10);
        euroField.setHorizontalAlignment(JLabel.RIGHT);
        euroField.setActionCommand("CONVERT_FROM_EURO");
        euroField.addActionListener(this);
        convField = new LimitedCharSetField(validChars, 10);
        convField.setHorizontalAlignment(JLabel.RIGHT);
        convField.setActionCommand("CONVERT_TO_EURO");
        convField.addActionListener(this);

        String shortName = curr.getCurrency().getShortName();
        euroLabel = new JLabel("EUR:");
        euroLabel.setIcon(Resources.getIcon("EUR_ICON"));
        convLabel = new JLabel(shortName + ":");
        convLabel.setIcon(Resources.getIcon(shortName + "_ICON"));

        JPanel labelColumn = new JPanel(new GridLayout(0, 1));
        labelColumn.add(euroLabel);
        labelColumn.add(convLabel);

        JPanel fieldColumn = new JPanel(new GridLayout(0, 1));
        fieldColumn.add(euroField);
        fieldColumn.add(convField);

        // add panels to content pane
        JPanel contentPane = new JPanel(new BorderLayout(8, 0));
        contentPane.setBorder(BorderFactory.createEmptyBorder(6, 6, 6, 6));
        contentPane.add(labelColumn, BorderLayout.CENTER);
        contentPane.add(fieldColumn, BorderLayout.EAST);
        getContentPane().add(contentPane);
        pack();

        // set frame properties
        setTitle(Resources.getString("app.title"));
        setResizable(false);
        setDefaultCloseOperation(EXIT_ON_CLOSE);
		setLocationRelativeTo(null);
    }

    public void actionPerformed(ActionEvent ae) {
        String ac = ae.getActionCommand();
        if (ac.equals("EXIT")) {
            System.exit(0);
        } else if (ac.equals("ABOUT")) {
            new AboutDialog(this).setVisible(true);
        } else if (ac.equals("CURRENCY_OVERVIEW")) {
            new CurrencyDialog(this, curr).setVisible(true);
        } else if (ac.equals("CONVERT_TO_EURO")) {
            convertCurrency(convField, euroField, false);
        } else if (ac.equals("CONVERT_FROM_EURO")) {
            convertCurrency(euroField, convField, true);
        } else if (ac.startsWith("CURRENCY_CHANGE_TO_")) {
        	String selected = ac.substring("CURRENCY_CHANGE_TO_".length());
          	System.out.println("Selected currency: " + selected);
            curr.setCurrency(selected);
            String shortName = curr.getCurrency().getShortName();
            convLabel.setIcon(Resources.getIcon(shortName + "_ICON"));
            convLabel.setText(shortName + ":");
            convertCurrency(euroField, convField, true);
        }
    }

    private void convertCurrency(JTextComponent inField,
    		JTextComponent outField, boolean isInputEuro) {
        // locking is needed since it would cause another
        // action event otherwise, resulting in a loop
        if (locked) {
            return;
        }
        locked = true;
        try {
            double inValue = nf.parse(inField.getText().trim()).doubleValue();
            double outValue;
            if (isInputEuro) {
                outValue = inValue * curr.getCurrency().getEuroValue();
            } else {
                outValue = inValue / curr.getCurrency().getEuroValue();
            }
            outField.setText(nf.format(outValue));
        } catch (NumberFormatException ignored) {
        } catch (ParseException ignored) {
        } finally {
            locked = false;
        }
    }

	// program starts here
    public static void main(String[] args) {
        new EuroCalc().setVisible(true);
    }
}
