package de.nwsnet.homework.eurocalc;

/*
 * Copyright (c) 2002, 2003 Jochen Kupperschmidt <jochen@kupperschmidt.de>
 * Released under the terms of the GNU General Public License
 *    _                               _
 *   | |_ ___ _____ ___ _ _ _ ___ ___| |_
 *   |   | . |     | ._| | | | . |  _| . /
 *   |_|_|___|_|_|_|___|_____|___|_| |_|_\
 *     http://homework.nwsnet.de/
 */

import javax.swing.JTextField;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.PlainDocument;

/**
 * A text field that reacts on changes and only accepts the characters in the
 * string given to its constructor.
 *
 * @author  <a href="mailto:jochen@kupperschmidt.de">Jochen Kupperschmidt</a>
 * @version 12-Jan-2003
 */
public class LimitedCharSetField extends JTextField {

	private String validChars;

    public LimitedCharSetField() {
        super();
    }

    public LimitedCharSetField(String validChars) {
		this.validChars = validChars;
		setDocument(new LimitedCharSetDocument());
	}

	protected LimitedCharSetField(String validChars, int cols) {
        this(validChars);
        super.setColumns(cols);
    }

	// an inner class for the custom document
	class LimitedCharSetDocument extends PlainDocument {
		// fire action on text insertion
		public void insertUpdate(DefaultDocumentEvent chng, AttributeSet attr) {
			fireActionPerformed();
		}

		// fire action on text removal
		public void postRemoveUpdate(DefaultDocumentEvent chng) {
			fireActionPerformed();
		}

		// validate the entered characters
		public void insertString(int offset, String str, AttributeSet a)
				throws BadLocationException {
			char[] source = str.toCharArray();
			char[] result = new char[source.length];
			int j = 0;
			for (int i = 0; i < result.length; i++) {
				if (validChars.indexOf(source[i]) != -1) {
					result[j++] = source[i];
				} else {
					System.err.println("Invalid char: " + source[i]);
				}
			}
			super.insertString(offset, new String(result, 0, j), a);
		}
	}

	public String toString() {
		return "LimitedCharSetField[" + validChars + "]";
	}
}
